@@ -8,16 +8,21 @@
  * @brief Compiler entry point for building the JavaScript package. File imports
  *  using the `@` symbol are aliased to `lib/ui-library/src`.
  */
-import PkpLoad from '../lib/pkp/js/load.js';
 
+// styles
+import '@/styles/_global.less';
+import '@/styles/tw-theme-vars.css';
+
+import PkpLoad from '../lib/pkp/js/load.js';
 // Import controllers used by OJS
 import Container from '@/components/Container/Container.vue';
 import AdvancedSearchReviewerContainer from '@/components/Container/AdvancedSearchReviewerContainer.vue';
 import Page from '@/components/Container/Page.vue';
+import WorkflowPageOJS from '@/pages/workflow/WorkflowPageOJS.vue';
+
 import AccessPage from '@/components/Container/AccessPage.vue';
 import AddContextContainer from '@/components/Container/AddContextContainer.vue';
 import AdminPage from '@/components/Container/AdminPage.vue';
-import CounterReportsPage from '@/components/Container/CounterReportsPage.vue';
 import DoiPage from '@/components/Container/DoiPageOJS.vue';
 import DecisionPage from '@/components/Container/DecisionPage.vue';
 import ImportExportPage from '@/components/Container/ImportExportPage.vue';
@@ -30,31 +35,24 @@ import StatsContextPage from '@/components/Container/StatsContextPage.vue';
 import StatsIssuesPage from '@/components/Container/StatsIssuesPage.vue';
 import StatsUsersPage from '@/components/Container/StatsUsersPage.vue';
 import SubmissionWizardPage from '@/components/Container/SubmissionWizardPage.vue';
-import WorkflowPage from '@/components/Container/WorkflowPageOJS.vue';
-import JobsPage from '@/components/Container/JobsPage.vue';
-import FailedJobsPage from '@/components/Container/FailedJobsPage.vue';
-import FailedJobDetailsPage from '@/components/Container/FailedJobDetailsPage.vue';
+import DashboardPage from '@/pages/dashboard/DashboardPage.vue';
 
-// Required by the URN plugin
-import FieldText from '@/components/Form/fields/FieldText.vue';
-import FieldPubId from '@/components/Form/fields/FieldPubId.vue';
+// Helper for initializing and tracking Vue controllers
+import VueRegistry from '../lib/pkp/js/classes/VueRegistry.js';
+VueRegistry.registerComponent('WorkflowPage', WorkflowPageOJS);
 
 // Expose Vue, the registry and controllers in a global var
-window.pkp = Object.assign(PkpLoad, {
+window.pkp = Object.assign(PkpLoad, window.pkp || {}, {
 	controllers: {
 		AccessPage,
 		AddContextContainer,
 		AdminPage,
 		AdvancedSearchReviewerContainer,
 		Container,
-		CounterReportsPage,
 		DoiPage,
 		DecisionPage,
 		ImportExportPage,
 		ManageEmailsPage,
-		JobsPage,
-		FailedJobsPage,
-		FailedJobDetailsPage,
 		Page,
 		SettingsPage,
 		StartSubmissionPage,
@@ -64,10 +62,6 @@ window.pkp = Object.assign(PkpLoad, {
 		StatsIssuesPage,
 		StatsUsersPage,
 		SubmissionWizardPage,
-		WorkflowPage,
+		DashboardPage,
 	},
 });
-
-// Required by the URN plugin
-window.pkp.Vue.component('field-text', FieldText);
-window.pkp.Vue.component('field-pub-id', FieldPubId);
