@@ -102,8 +102,7 @@ class PKPContainer extends Container
                     if ($pkpRouter instanceof APIRouter && app('router')->getRoutes()->count()) {
                         if ($exception instanceof \Illuminate\Validation\ValidationException) {
                             return response()
-                                ->json($exception->errors(), $exception->status)
-                                ->send();
+                                ->json($exception->errors(), $exception->status);
                         }
 
                         return response()->json(
@@ -113,7 +112,7 @@ class PKPContainer extends Container
                             in_array($exception->getCode(), array_keys(Response::$statusTexts))
                                 ? $exception->getCode()
                                 : Response::HTTP_INTERNAL_SERVER_ERROR
-                        )->send();
+                        );
                     }
 
                     return null;
@@ -501,7 +500,7 @@ class PKPContainer extends Container
             : Config::getVar('email', 'default');
 
         if (!$default) {
-            throw new Exception('Mailer driver isn\'t specified in the application\'s config');
+            throw new Exception('The mailer driver isn\'t specified in the config.inc.php configuration file. See the "default" setting in the [email] configuration. Configuration details are available in the config.TEMPLATE.inc.php template.');
         }
 
         return $default;
