@@ -17,8 +17,9 @@
 namespace PKP\services;
 
 use APP\core\Application;
+use APP\core\PageRouter;
 use APP\template\TemplateManager;
-use PKP\cache\FileCache;
+use Illuminate\Support\Facades\Cache;
 use PKP\core\PKPApplication;
 use PKP\db\DAORegistry;
 use PKP\facades\Locale;
@@ -39,6 +40,8 @@ class PKPNavigationMenuService
      * Return all default navigationMenuItemTypes.
      *
      * @return array
+     *
+     * @hook NavigationMenus::itemTypes [[&$types]]
      */
     public function getMenuItemTypes()
     {
@@ -56,10 +59,9 @@ class PKPNavigationMenuService
                 'description' => __('manager.navigationMenus.about.description'),
                 'conditionalWarning' => __('manager.navigationMenus.about.conditionalWarning'),
             ],
-            NavigationMenuItem::NMI_TYPE_EDITORIAL_TEAM => [
-                'title' => __('about.editorialTeam'),
-                'description' => __('manager.navigationMenus.editorialTeam.description'),
-                'conditionalWarning' => __('manager.navigationMenus.editorialTeam.conditionalWarning'),
+            NavigationMenuItem::NMI_TYPE_MASTHEAD => [
+                'title' => __('common.editorialMasthead'),
+                'description' => __('manager.navigationMenus.editorialMasthead.description'),
             ],
             NavigationMenuItem::NMI_TYPE_SUBMISSIONS => [
                 'title' => __('about.submissions'),
@@ -125,6 +127,8 @@ class PKPNavigationMenuService
      * Return all custom edit navigationMenuItemTypes Templates.
      *
      * @return array
+     *
+     * @hook NavigationMenus::itemCustomTemplates [[&$templates]]
      */
     public function getMenuItemCustomEditTemplates()
     {
@@ -144,6 +148,8 @@ class PKPNavigationMenuService
 
     /**
      * Callback for display menu item functionality
+     *
+     * @hook NavigationMenus::displaySettings [[$navigationMenuItem, $navigationMenu]]
      */
     public function getDisplayStatus(&$navigationMenuItem, &$navigationMenu)
     {
@@ -156,7 +162,7 @@ class PKPNavigationMenuService
         $context = $request->getContext();
         $currentUser = $request->getUser();
 
-        $contextId = $context ? $context->getId() : \PKP\core\PKPApplication::CONTEXT_ID_NONE;
+        $contextId = $context ? $context->getId() : \PKP\core\PKPApplication::SITE_CONTEXT_ID;
 
         // Transform an item title if the title includes a {$variable}
         $this->transformNavMenuItemTitle($templateMgr, $navigationMenuItem);
@@ -171,9 +177,6 @@ class PKPNavigationMenuService
                     || (!$context && $request->getSite()->getData('enableAnnouncements'))
                 );
                 break;
-            case NavigationMenuItem::NMI_TYPE_EDITORIAL_TEAM:
-                $navigationMenuItem->setIsDisplayed($context && $context->getLocalizedData('editorialTeam'));
-                break;
             case NavigationMenuItem::NMI_TYPE_CONTACT:
                 $navigationMenuItem->setIsDisplayed($context && ($context->getData('mailingAddress') || $context->getData('contactName')));
                 break;
@@ -189,7 +192,7 @@ class PKPNavigationMenuService
                 $navigationMenuItem->setIsDisplayed($isUserLoggedIn);
                 break;
             case NavigationMenuItem::NMI_TYPE_ADMINISTRATION:
-                $navigationMenuItem->setIsDisplayed($isUserLoggedIn && $currentUser->hasRole([Role::ROLE_ID_SITE_ADMIN], PKPApplication::CONTEXT_SITE));
+                $navigationMenuItem->setIsDisplayed($isUserLoggedIn && $currentUser->hasRole([Role::ROLE_ID_SITE_ADMIN], PKPApplication::SITE_CONTEXT_ID));
                 break;
             case NavigationMenuItem::NMI_TYPE_PRIVACY:
                 $navigationMenuItem->setIsDisplayed($context && $context->getLocalizedData('privacyStatement'));
@@ -207,7 +210,7 @@ class PKPNavigationMenuService
                     break;
                 case NavigationMenuItem::NMI_TYPE_USER_DASHBOARD:
                     $templateMgr->assign('navigationMenuItem', $navigationMenuItem);
-                    if ($currentUser->hasRole([Role::ROLE_ID_MANAGER, Role::ROLE_ID_ASSISTANT, Role::ROLE_ID_REVIEWER, Role::ROLE_ID_AUTHOR], $contextId) || $currentUser->hasRole([Role::ROLE_ID_SITE_ADMIN], PKPApplication::CONTEXT_SITE)) {
+                    if ($currentUser->hasRole([Role::ROLE_ID_MANAGER, Role::ROLE_ID_ASSISTANT, Role::ROLE_ID_REVIEWER, Role::ROLE_ID_AUTHOR], $contextId) || $currentUser->hasRole([Role::ROLE_ID_SITE_ADMIN], PKPApplication::SITE_CONTEXT_ID)) {
                         $displayTitle = $templateMgr->fetch('frontend/components/navigationMenus/dashboardMenuItem.tpl');
                         $navigationMenuItem->setTitle($displayTitle, Locale::getLocale());
                     }
@@ -246,13 +249,13 @@ class PKPNavigationMenuService
                         null
                     ));
                     break;
-                case NavigationMenuItem::NMI_TYPE_EDITORIAL_TEAM:
+                case NavigationMenuItem::NMI_TYPE_MASTHEAD:
                     $navigationMenuItem->setUrl($dispatcher->url(
                         $request,
                         PKPApplication::ROUTE_PAGE,
                         null,
                         'about',
-                        'editorialTeam',
+                        'editorialMasthead',
                         null
                     ));
                     break;
@@ -290,22 +293,19 @@ class PKPNavigationMenuService
                     $navigationMenuItem->setUrl($dispatcher->url(
                         $request,
                         PKPApplication::ROUTE_PAGE,
-                        'index',
+                        Application::SITE_CONTEXT_PATH,
                         'admin',
                         'index',
                         null
                     ));
                     break;
                 case NavigationMenuItem::NMI_TYPE_USER_DASHBOARD:
-                    if ($currentUser->hasRole([Role::ROLE_ID_MANAGER, Role::ROLE_ID_ASSISTANT, Role::ROLE_ID_REVIEWER, Role::ROLE_ID_AUTHOR], $contextId) || $currentUser->hasRole([Role::ROLE_ID_SITE_ADMIN], PKPApplication::CONTEXT_SITE)) {
-                        $navigationMenuItem->setUrl($dispatcher->url(
-                            $request,
-                            PKPApplication::ROUTE_PAGE,
-                            null,
-                            'submissions',
-                            null,
-                            null
-                        ));
+                    if ($currentUser->hasRole([Role::ROLE_ID_MANAGER, Role::ROLE_ID_ASSISTANT, Role::ROLE_ID_REVIEWER, Role::ROLE_ID_AUTHOR], $contextId) || $currentUser->hasRole([Role::ROLE_ID_SITE_ADMIN], PKPApplication::SITE_CONTEXT_ID)) {
+                        $pkpPageRouter = $request->getRouter();  /** @var \PKP\core\PKPPageRouter $pkpPageRouter */
+
+                        if ($pkpPageRouter instanceof PageRouter) {
+                            $navigationMenuItem->setUrl($pkpPageRouter->getHomeUrl($request));
+                        }
                     } else {
                         $navigationMenuItem->setUrl($dispatcher->url(
                             $request,
@@ -384,7 +384,7 @@ class PKPNavigationMenuService
         $templateMgr->assign('navigationMenuItem', $navigationMenuItem);
     }
 
-    public function loadMenuTree(&$navigationMenu)
+    public function loadMenuTree(NavigationMenu $navigationMenu)
     {
         /** @var NavigationMenuItemDAO */
         $navigationMenuItemDao = DAORegistry::getDAO('NavigationMenuItemDAO');
@@ -428,35 +428,26 @@ class PKPNavigationMenuService
             }
         }
         /** @var NavigationMenuDAO */
-        $navigationMenuDao = DAORegistry::getDAO('NavigationMenuDAO');
-        $cache = $navigationMenuDao->getCache($navigationMenu->getId());
-        $json = json_encode($navigationMenu);
-        $cache->setEntireCache($json);
+        Cache::put($cacheId = "navigationMenu-{$navigationMenu->getId()}", json_encode($navigationMenu), 60 * 60 * 24);
     }
 
     /**
      * Get a tree of NavigationMenuItems assigned to this menu
-     *
-     * @param NavigationMenu $navigationMenu
-     *
      */
-    public function getMenuTree(&$navigationMenu)
+    public function getMenuTree(NavigationMenu &$navigationMenu): void
     {
         /** @var NavigationMenuDAO */
         $navigationMenuDao = DAORegistry::getDAO('NavigationMenuDAO');
-        /** @var FileCache */
-        $cache = $navigationMenuDao->getCache($navigationMenu->getId());
-        if ($cache->cache) {
-            $navigationMenu = json_decode($cache->cache, true);
-            $navigationMenu = $this->arrayToObject('NavigationMenu', $navigationMenu);
-            $this->loadMenuTreeDisplayState($navigationMenu);
-            return;
+        $cachedNavigationMenu = Cache::get("navigationMenu-{$navigationMenu->getId()}");
+        if ($cachedNavigationMenu) {
+            $navigationMenu = $this->arrayToObject('NavigationMenu', json_decode($cachedNavigationMenu, true));
+        } else {
+            $this->loadMenuTree($navigationMenu);
         }
-        $this->loadMenuTree($navigationMenu);
         $this->loadMenuTreeDisplayState($navigationMenu);
     }
 
-    private function loadMenuTreeDisplayState(&$navigationMenu)
+    private function loadMenuTreeDisplayState(NavigationMenu $navigationMenu): void
     {
         foreach ($navigationMenu->menuTree as $assignment) {
             $nmi = $assignment->getMenuItem();
@@ -526,7 +517,7 @@ class PKPNavigationMenuService
      */
     public function transformNavMenuItemTitle($templateMgr, &$navigationMenuItem)
     {
-        $this->setNMITitleLocalized($navigationMenuItem);
+        $this->setAllNMILocalizedTitles($navigationMenuItem);
 
         $title = $navigationMenuItem->getLocalizedTitle();
         $prefix = '{$';
@@ -631,6 +622,8 @@ class PKPNavigationMenuService
             foreach ($supportedFormLocales as $supportedFormLocale => $supportedFormLocaleValue) {
                 if ($localizedTitle = $nmi->getTitle($supportedFormLocale)) {
                     $nmi->setTitle($localizedTitle, $supportedFormLocale);
+                } elseif ($nmi->getTitleLocaleKey() === '{$loggedInUsername}') {
+                    $nmi->setTitle($nmi->getTitleLocaleKey(), Locale::getLocale());
                 } else {
                     $nmi->setTitle(__($nmi->getTitleLocaleKey(), [], $supportedFormLocale), $supportedFormLocale);
                 }
@@ -648,9 +641,9 @@ class PKPNavigationMenuService
     {
         $request = Application::get()->getRequest();
 
-        $page = & $args[0];
-        $op = & $args[1];
-        $handler = & $args[3];
+        $page = &$args[0];
+        $op = &$args[1];
+        $handler = &$args[3];
 
         // Construct a path to look for
         $path = $page;
@@ -666,7 +659,7 @@ class PKPNavigationMenuService
         $navigationMenuItemDao = DAORegistry::getDAO('NavigationMenuItemDAO');
 
         $context = $request->getContext();
-        $contextId = $context ? $context->getId() : \PKP\core\PKPApplication::CONTEXT_ID_NONE;
+        $contextId = $context ? $context->getId() : \PKP\core\PKPApplication::SITE_CONTEXT_ID;
         $customNMI = $navigationMenuItemDao->getByPath($contextId, $path);
 
         // Check if a custom NMI with the requested path exists
