@@ -21,11 +21,17 @@ use APP\issue\Issue;
 use APP\journal\Journal;
 use APP\journal\JournalDAO;
 use APP\submission\Submission;
-use PKP\citation\CitationDAO;
+use DOMDocument;
+use DOMElement;
+use DOMException;
+use PKP\citation\Citation;
 use PKP\core\PKPString;
 use PKP\db\DAORegistry;
 use PKP\filter\PersistableFilter;
+use PKP\i18n\interfaces\LocaleInterface;
 use PKP\i18n\LocaleConversion;
+use PKP\plugins\Plugin;
+use PKP\plugins\PluginRegistry;
 
 class ArticlePubMedXmlFilter extends PersistableFilter
 {
@@ -34,10 +40,8 @@ class ArticlePubMedXmlFilter extends PersistableFilter
     //
     /**
      * Get the representation export filter group name
-     *
-     * @return string
      */
-    public function getRepresentationExportFilterGroupName()
+    public function getRepresentationExportFilterGroupName(): string
     {
         return 'article-galley=>pubmed-xml';
     }
@@ -46,13 +50,14 @@ class ArticlePubMedXmlFilter extends PersistableFilter
     // Implement template methods from Filter
     //
     /**
-     * @see Filter::process()
-     *
      * @param array $submissions Array of submissions
      *
-     * @return \DOMDocument
+     * @throws DOMException
+     *
+     * @see Filter::process()
+     *
      */
-    public function &process(&$submissions)
+    public function &process(&$submissions): DOMDocument
     {
         // Create the XML document
         $implementation = new \DOMImplementation();
@@ -61,28 +66,31 @@ class ArticlePubMedXmlFilter extends PersistableFilter
         $doc->preserveWhiteSpace = false;
         $doc->formatOutput = true;
 
+        PluginRegistry::loadCategory('importexport');
+        $plugin = PluginRegistry::getPlugin('importexport', 'PubMedExportPlugin');
+
         $journalDao = DAORegistry::getDAO('JournalDAO'); /** @var JournalDAO $journalDao */
         $journal = null;
 
         $rootNode = $doc->createElement('ArticleSet');
         foreach ($submissions as $submission) {
             // Fetch associated objects
-            if ($journal?->getId() !== $submission->getContextId()) {
-                $journal = $journalDao->getById($submission->getContextId());
+            if ($journal?->getId() !== $submission->getData('contextId')) {
+                $journal = $journalDao->getById($submission->getData('contextId'));
             }
             $issue = Repo::issue()->getBySubmissionId($submission->getId());
             $issue = $issue?->getJournalId() === $journal->getId() ? $issue : null;
 
             $articleNode = $doc->createElement('Article');
-            $articleNode->appendChild($this->createJournalNode($doc, $journal, $issue, $submission));
+            $articleNode->appendChild($this->createJournalNode($doc, $plugin, $journal, $issue, $submission));
 
             $publication = $submission->getCurrentPublication();
 
-            $locale = $publication->getData('locale');
-            if ($locale == 'en') {
-                $articleNode->appendChild($doc->createElement('ArticleTitle'))->appendChild($doc->createTextNode($publication->getLocalizedTitle($locale, 'html')));
+            $publicationLocale = $publication->getData('locale');
+            if ($publicationLocale == LocaleInterface::DEFAULT_LOCALE) {
+                $articleNode->appendChild($doc->createElement('ArticleTitle'))->appendChild($doc->createTextNode($publication->getLocalizedTitle($publicationLocale, 'html')));
             } else {
-                $articleNode->appendChild($doc->createElement('VernacularTitle'))->appendChild($doc->createTextNode($publication->getLocalizedTitle($locale, 'html')));
+                $articleNode->appendChild($doc->createElement('VernacularTitle'))->appendChild($doc->createTextNode($publication->getLocalizedTitle($publicationLocale, 'html')));
             }
 
             $startPage = $publication->getStartingPage();
@@ -100,7 +108,7 @@ class ArticlePubMedXmlFilter extends PersistableFilter
                 $articleNode->appendChild($doiNode);
             }
 
-            $articleNode->appendChild($doc->createElement('Language'))->appendChild($doc->createTextNode(LocaleConversion::get3LetterFrom2LetterIsoLanguage(substr($locale, 0, 2))));
+            $articleNode->appendChild($doc->createElement('Language'))->appendChild($doc->createTextNode(LocaleConversion::get3LetterIsoFromLocale($publicationLocale)));
 
             $authorListNode = $doc->createElement('AuthorList');
             foreach ($publication->getData('authors') ?? [] as $author) {
@@ -119,7 +127,7 @@ class ArticlePubMedXmlFilter extends PersistableFilter
 
             // History
             $historyNode = $doc->createElement('History');
-            $historyNode->appendChild($this->generatePubDateDom($doc, $submission->getDateSubmitted(), 'received'));
+            $historyNode->appendChild($this->generatePubDateDom($doc, $submission->getData('dateSubmitted'), 'received'));
 
             $editorDecision = Repo::decision()->getCollector()
                 ->filterBySubmissionIds([$submission->getId()])
@@ -133,12 +141,13 @@ class ArticlePubMedXmlFilter extends PersistableFilter
 
             // FIXME: Revision dates
 
-            if ($abstract = PKPString::html2text($publication->getLocalizedData('abstract', $locale))) {
+            if ($abstract = PKPString::html2text($publication->getLocalizedData('abstract', $publicationLocale))) {
                 $articleNode->appendChild($doc->createElement('Abstract'))->appendChild($doc->createTextNode($abstract));
             }
 
             // Keywords
-            $keywords = $publication->getData('keywords', $locale);
+            $keywords = $publication->getData('keywords', $publicationLocale);
+
             if (!empty($keywords)) {
                 $objectListNode = $doc->createElement('ObjectList');
                 foreach ($keywords as $keyword) {
@@ -154,15 +163,13 @@ class ArticlePubMedXmlFilter extends PersistableFilter
             }
 
             // References
-            $citationDao = DAORegistry::getDAO('CitationDAO'); /** @var CitationDAO $citationDao */
-            $citations = $citationDao->getByPublicationId($publication->getId())->toAssociativeArray();
-            if (!empty($citations)) {
+            $rawCitations = $publication->getData('citations');
+            if (!empty($rawCitations)) {
                 $referenceListNode = $doc->createElement('ReferenceList');
-                foreach ($citations as $submissionCitation) {
-                    $rawCitation = $submissionCitation->getRawCitation();
+                foreach ($rawCitations as $rawCitation) { /** @var Citation $rawCitation */
                     $referenceNode = $doc->createElement('Reference');
                     $citationNode = $doc->createElement('Citation');
-                    $citationNode->appendChild($doc->createTextNode($rawCitation));
+                    $citationNode->appendChild($doc->createTextNode($rawCitation->getRawCitation()));
                     $referenceNode->appendChild($citationNode);
                     $referenceListNode->appendChild($referenceNode);
                 }
@@ -178,21 +185,28 @@ class ArticlePubMedXmlFilter extends PersistableFilter
     /**
      * Construct and return a Journal element.
      *
-     * @param \DOMDocument $doc
+     * @param DOMDocument $doc
+     * @param Plugin $plugin
      * @param Journal $journal
      * @param Issue $issue
      * @param Submission $submission
+     *
+     * @throws DOMException
      */
-    public function createJournalNode($doc, $journal, $issue, $submission)
+    public function createJournalNode($doc, $plugin, $journal, $issue, $submission): DOMElement
     {
+        $nlmTitle = $plugin->getSetting($journal->getId(), 'nlmTitle');
         $journalNode = $doc->createElement('Journal');
 
         $publisherNameNode = $doc->createElement('PublisherName');
         $publisherNameNode->appendChild($doc->createTextNode($journal->getData('publisherInstitution')));
         $journalNode->appendChild($publisherNameNode);
 
+        $journalTitle = $nlmTitle ?? $journal->getName($journal->getPrimaryLocale());
+
         $journalTitleNode = $doc->createElement('JournalTitle');
-        $journalTitleNode->appendChild($doc->createTextNode($journal->getName($journal->getPrimaryLocale())));
+        $journalTitleNode->appendChild($doc->createTextNode($journalTitle));
+
         $journalNode->appendChild($journalTitleNode);
 
         // check various ISSN fields to create the ISSN tag
@@ -228,36 +242,48 @@ class ArticlePubMedXmlFilter extends PersistableFilter
     /**
      * Generate and return an author node representing the supplied author.
      *
-     * @param \DOMDocument $doc
+     * @param DOMDocument $doc
      * @param Journal $journal
      * @param Issue $issue
      * @param Submission $submission
      * @param Author $author
      *
-     * @return \DOMElement
+     * @throws DOMException
+     *
+     * @return DOMElement
      */
     public function generateAuthorNode($doc, $journal, $issue, $submission, $author)
     {
         $authorElement = $doc->createElement('Author');
+        $publication = $submission->getCurrentPublication();
+        $publicationLocale = $publication->getData('locale');
 
-        if (empty($author->getLocalizedFamilyName())) {
+        if (empty($author->getFamilyName($publicationLocale))) {
             $authorElement->appendChild($node = $doc->createElement('FirstName'));
             $node->setAttribute('EmptyYN', 'Y');
-            $authorElement->appendChild($doc->createElement('LastName'))->appendChild($doc->createTextNode(ucfirst($author->getLocalizedGivenName())));
+            $authorElement->appendChild($doc->createElement('LastName'))->appendChild($doc->createTextNode(ucfirst($author->getGivenName($publicationLocale))));
         } else {
-            $authorElement->appendChild($doc->createElement('FirstName'))->appendChild($doc->createTextNode(ucfirst($author->getLocalizedGivenName())));
-            $authorElement->appendChild($doc->createElement('LastName'))->appendChild($doc->createTextNode(ucfirst($author->getLocalizedFamilyName())));
+            $authorElement->appendChild($doc->createElement('FirstName'))->appendChild($doc->createTextNode(ucfirst($author->getGivenName($publicationLocale))));
+            $authorElement->appendChild($doc->createElement('LastName'))->appendChild($doc->createTextNode(ucfirst($author->getFamilyName($publicationLocale))));
         }
-        if ($author->getLocalizedAffiliation()) {
-            $authorElement->appendChild($doc->createElement('Affiliation'))->appendChild($doc->createTextNode($author->getLocalizedAffiliation()));
+        foreach ($author->getAffiliations() as $affiliation) {
+            $affiliationInfoElement = $doc->createElement('AffiliationInfo');
+            $affiliationInfoElement->appendChild($doc->createElement('Affiliation'))->appendChild($doc->createTextNode($affiliation->getLocalizedName($publicationLocale)));
+            if ($affiliation->getRor()) {
+                $affiliationInfoElement->appendChild($identifierNode = $doc->createElement('Identifier'))->appendChild($doc->createTextNode($affiliation->getRor()));
+                $identifierNode->setAttribute('Source', 'ROR');
+            }
+            $authorElement->appendChild($affiliationInfoElement);
         }
-        // We're storing the ORCID with a URL (http://orcid.org/{$ID}), but the XML expects just the ID
-        $orcidId = explode('/', trim($author->getData('orcid') ?? '', '/'));
-        $orcidId = array_pop($orcidId);
-        if ($orcidId) {
-            $orcidNode = $authorElement->appendChild($doc->createElement('Identifier'));
-            $orcidNode->setAttribute('Source', 'ORCID');
-            $orcidNode->appendChild($doc->createTextNode($orcidId));
+        if ($author->getData('orcid') && $author->getData('orcidIsVerified')) {
+            // We're storing the ORCID with a URL (http://orcid.org/{$ID}), but the XML expects just the ID
+            $orcidId = explode('/', trim($author->getData('orcid') ?? '', '/'));
+            $orcidId = array_pop($orcidId);
+            if ($orcidId) {
+                $orcidNode = $authorElement->appendChild($doc->createElement('Identifier'));
+                $orcidNode->setAttribute('Source', 'ORCID');
+                $orcidNode->appendChild($doc->createTextNode($orcidId));
+            }
         }
 
         return $authorElement;
@@ -266,13 +292,13 @@ class ArticlePubMedXmlFilter extends PersistableFilter
     /**
      * Generate and return a date element per the PubMed standard.
      *
-     * @param \DOMDocument $doc
+     * @param DOMDocument $doc
      * @param string $pubDate
      * @param string $pubStatus
      *
-     * @return \DOMElement
+     * @throws DOMException
      */
-    public function generatePubDateDom($doc, $pubDate, $pubStatus)
+    public function generatePubDateDom($doc, $pubDate, $pubStatus): DOMElement
     {
         $pubDateNode = $doc->createElement('PubDate');
         $pubDateNode->setAttribute('PubStatus', $pubStatus);
